/********************************************************************************/
/*         (c) Copyright 2018, Real-Time Innovations, All rights reserved.      */
/*                                                                              */
/* RTI grants Licensee a license to use, modify, compile, and create            */ 
/* derivative works of the software solely for use with RTI Connext DDS.        */ 
/* Licensee may redistribute copies of the software provided that all such      */
/* copies are subject to this license. The software is provided "as is", with   */
/* no warranty of any type, including any warranty for fitness for any purpose. */
/* RTI is under no obligation to maintain or support the software.  RTI shall   */
/* not be liable for any incidental or consequential damages arising out of the */
/* use or inability to use the software.                                        */
/********************************************************************************/
#ifndef __GENERIC_SUBSCRIBER__
#define __GENERIC_SUBSCRIBER__

#include <dds/dds.hpp>
#include <rti/config/Version.hpp>

#include <string>

/**
 * A GenericSubscriber requires the factory to be configured to
 * create entities in a disabled state prior to instantiation.  
 * It will not function otherwise.
 */
class GenericSubscriber {
public:
    /**
     * Creates the DDS entities for the subscriber.
     * @param domain_id the domain ID.
     * @param verbose provide a higher level of output.
     */
    GenericSubscriber(int domain_id,
             bool verbose);

    /**
     * Subscriber destructor
     */
    ~GenericSubscriber(); 

    /**
     * List the topics available in domain 
     */
    void list_topics(void);

    /**
     * Start receiving the data.
     */
    void receive(const std::string& topicName);

private:
    class GenericSubscriberImpl;
    std::unique_ptr<GenericSubscriberImpl> impl;
};

#endif